package com.pms.ocp.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;

import com.pms.ocp.common.utils.RandomStringUtils;
import com.pms.ocp.mapper.OcpApiBaseMapper;
import com.pms.ocp.mapper.OcpApiTreeMapper;
import com.pms.ocp.model.dto.*;
import com.pms.ocp.model.entity.OcpApiGroup;

import com.pms.ocp.service.OcpApiTreeService;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.sql.Timestamp;
import java.util.List;
import java.util.stream.Stream;


@Service
@Slf4j
public class OcpApiTreeServiceImpl extends ServiceImpl<OcpApiTreeMapper,OcpApiGroup> implements OcpApiTreeService {


    @Autowired
    private OcpApiTreeMapper mapper;

    @Autowired
    private OcpApiBaseMapper ocpApiBaseMapper;

    /**
     * 服务树分类
     *
     * @return
     */

    @Override
    public List<OcpApiGroup> getByGroup(Long apiGroupPromotionType,String apiGroupCode) {

            if (!("".equals(apiGroupPromotionType)) && StringUtils.isBlank(apiGroupCode)){
                List<OcpApiGroup> ocpApiGroups = mapper.selectTwoApiGroups(apiGroupPromotionType);
                return ocpApiGroups;
            } else if(!("".equals(apiGroupPromotionType)) && !(StringUtils.isBlank(apiGroupCode))){
                List<OcpApiGroup> ocpApiGroups = mapper.selectThreeApiGroupsList(apiGroupPromotionType, apiGroupCode);
                return ocpApiGroups;
            }

            return null;
        }


    /**
     * 新增服务分类
     *
     * @param
     */
    @Override
    public boolean insertTree(OcpApiGroup ocpApiGroup) {
        Timestamp timestamp = new Timestamp(System.currentTimeMillis());
        String code = RandomStringUtils.getRandomString(6);
        boolean flag = true;
        List<OcpApiGroup> ocpApiGroups = mapper.selectList(null);
       Stream<OcpApiGroup> ocpApiGroupStream = ocpApiGroups.stream().filter(item -> item.getApiGroupCode().equals(ocpApiGroup.getApiGroupPcode()));
        Stream<OcpApiGroup> apiGroupStream1 =  ocpApiGroupStream.filter(ocp -> ocp.getApiGroupName().equals(ocpApiGroup.getApiGroupName()));
        if (!(apiGroupStream1.isParallel())){
            OcpApiGroup ocpApi = new OcpApiGroup();
            BeanUtils.copyProperties(ocpApiGroup,ocpApi);
            ocpApi.setApiGroupPromotionType(ocpApiGroup.getApiGroupPromotionType());
            ocpApi.setObjId("");
            ocpApi.setApiGroupMtime(timestamp);
            ocpApi.setApiGroupCtime(timestamp);
            ocpApi.setApiGroupPcode(ocpApiGroup.getApiGroupCode());
            ocpApi.setApiGroupCode(code);
            mapper.insert(ocpApi);
            ocpApiGroup.setApiGroupLevel(ocpApiGroup.getApiGroupLevel() + 1);
        }else {
            return false;
        }
        return flag;

    }


    /**
     * 修改服务分类
     *
     * @param
     */
    @Override
    public boolean updataOcpTree(OcpApiGroup ocpApiGroup) {
        boolean falg = true;
        List<OcpApiGroup> ocpApiGroups = mapper.selectList(null);
        for (OcpApiGroup apiGroup : ocpApiGroups) {
            String code = apiGroup.getApiGroupCode();
            if (code == ocpApiGroup.getApiGroupCode()) {
                falg = false;
                break;
            }
        }
        mapper.updateById(ocpApiGroup);
        return falg;
    }


    /**
     * 删除服务分类
     *
     * @param ocpApiGroup
     */
    @Override
        public boolean deleteOcpTree(OcpApiGroup ocpApiGroup) {
        boolean flag = true;
        String objId = ocpApiGroup.getObjId();
        OcpApiGroup ocpApiGroup1 = mapper.selectById(objId);
        List<OcpApiGroup> ocpApiGroups = mapper.selectList(null);
        for (OcpApiGroup apiGroup : ocpApiGroups) {
            if ((ocpApiGroup1.getApiGroupCode()).equals(apiGroup.getApiGroupPcode())){
                    flag = false;
                    break;
                }
        }
        if (flag){
            mapper.deleteById(objId);
        }
        return flag;
    }


    /**
     * 服务列表分级查询
     *
     * @param pageGroupDto
     * @return
     */
    @Override
    public Page<OcpApiGroup> getOnePages(PageGroupDto pageGroupDto) {

        Page pageInfo = new Page(pageGroupDto.getPageNum(), pageGroupDto.getPageSize());
        if (StringUtils.isBlank(pageGroupDto.getApiGroupCode())){
            LambdaQueryWrapper<OcpApiGroup> lambdaQueryWrapper = new LambdaQueryWrapper();
             lambdaQueryWrapper.eq(OcpApiGroup::getApiGroupPromotionType, pageGroupDto.getApiGroupPromotionType());
           pageInfo =  mapper.selectPage(pageInfo,lambdaQueryWrapper);
        }else if (!(StringUtils.isBlank(pageGroupDto.getApiGroupCode()))){
            List<OcpApiGroup> ocpApiGroups = mapper.selectLists(pageGroupDto.getApiGroupPromotionType(),pageGroupDto.getApiGroupCode(),pageGroupDto.getApiGroupLevel());
            pageInfo.setRecords(ocpApiGroups);
            pageInfo =  mapper.selectPage(pageInfo, null);
        }
        return pageInfo;
    }
}
